@@ -94,7 +94,7 @@ fn feature_builtins() -> Vec<(Builtin, Pubkey, ActivationType)> {
                 solana_sdk::compute_budget::id(),
                 solana_compute_budget_program::process_instruction,
             ),
-            feature_set::tx_wide_compute_cap::id(),
+            feature_set::add_compute_budget_program::id(),
             ActivationType::NewProgram,
         ),
         (
